------------------------------------------------------------------------------
--  Test: Auditing_003
--  Verification: This test verifies that the default Common Criteria trace
--      rollover option is set and working correctly
--
--  Test Details:
--      1.  The default Common Criteria trace options will be verified
--      2.  Enough events will be written to the trace to cause a rollover
--      3.  The rollover will be verified by making sure the trace file path
--             has been updated
--
--  Test Dependenices:
--      1.  This test must be executed as a sysadmin
------------------------------------------------------------------------------

DECLARE @error_message 	nvarchar(1024)

BEGIN TRY
	SET NOCOUNT ON

	------------------------------------------------------------------------------
	-- If the version is not SP2 then do not run the script
	------------------------------------------------------------------------------
	IF SERVERPROPERTY( N'ProductVersion' ) <> N'10.0.4000.0'
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Auditing_003] This test can only be executed on SQL Server 2008 SP2';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify test dependencies
	------------------------------------------------------------------------------
	IF ( IS_SRVROLEMEMBER( N'sysadmin' ) = 0 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Auditing_003] This test must be executed by a sysadmin';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify default Common Criteria trace is available and rollover/shutdown
	--     are set to 1
	------------------------------------------------------------------------------
	DECLARE @trace_path       nvarchar(4000)
	DECLARE @trace_id         int
	DECLARE @trace_max_size   int

	IF ( ( SELECT count(*) FROM sys.traces WHERE path LIKE '%cc_trace_%' AND is_rollover = 1 AND is_shutdown = 1 ) <> 1 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Auditing_003] The default Common Criteria trace does not exist or has incorrect default options';
		PRINT @error_message
		RETURN;
	END

	SELECT @trace_path = path, @trace_id = id, @trace_max_size = max_size FROM sys.traces WHERE path LIKE '%cc_trace_%';

	------------------------------------------------------------------------------
	-- Write enough events into the trace to cause a rollover
	------------------------------------------------------------------------------
	DECLARE @counter          int
	SET     @counter          = 5000 * @trace_max_size
	WHILE ( @counter > 0 )
	BEGIN
		BEGIN TRY
			RAISERROR ( 'Sample event for Common Criteria script verification: Rollover case. ''%i''', 11, 1, @counter );
		END TRY
		BEGIN CATCH
		END CATCH

		SELECT @counter = @counter - 1;
	END
	
	------------------------------------------------------------------------------
	-- Verify rollover completed by comparing the trace files
	------------------------------------------------------------------------------
	DECLARE @new_trace_path       nvarchar(4000)

	IF ( ( SELECT count(*) FROM sys.traces WHERE path LIKE '%cc_trace_%' ) <> 1 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Auditing_003] The default Common Criteria trace does not exist after rollover verifications';
		PRINT @error_message
		RETURN;
	END

	SELECT @new_trace_path = path FROM sys.traces WHERE path LIKE '%cc_trace_%';

	IF ( @trace_path = @new_trace_path )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Auditing_003] The default Common Criteria trace did not rollover';
		PRINT @error_message
		RETURN;
	END

	PRINT 'TESTRESULT: PASS [Auditing_003]';
END TRY
BEGIN CATCH

	SET @error_message = N'TESTRESULT: FAIL [Auditing_003] ' + error_message();
	PRINT @error_message

END CATCH
go

