------------------------------------------------------------------------------
--  Test: Session_Handling_004
--  Verification: This test verifies that a login can be denied access via 
--      the sp_deny_logon Common Criteria stored procedure
--
--  Test Details:
--      1.  Deny access to LGN_Session_Handling via the proc
--
--  Test Dependenices:
--      1.  This test must be executed as a sysadmin
------------------------------------------------------------------------------

DECLARE @error_message 	nvarchar(1024)

BEGIN TRY
	SET NOCOUNT ON

	------------------------------------------------------------------------------
	-- If the version is not SP2 then do not run the script
	------------------------------------------------------------------------------
	IF SERVERPROPERTY( N'ProductVersion' ) <> N'10.0.4000.0'
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_004] This test can only be executed on SQL Server 2008 SP2';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Verify test dependencies
	------------------------------------------------------------------------------
	IF ( IS_SRVROLEMEMBER( N'sysadmin' ) = 0 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_004] This test must be executed by a sysadmin';
		PRINT @error_message
		RETURN;
	END

	------------------------------------------------------------------------------
	-- Deny access for the next 10 minutes
	------------------------------------------------------------------------------
	DECLARE @start_day 	tinyint
	DECLARE @end_day 	tinyint
	DECLARE @start_time	nvarchar(12)
	DECLARE @end_time	nvarchar(12)

	SET @start_day = DATEPART(dw, GETDATE());
	SET @end_day   = DATEPART(dw, GETDATE());

	SET @start_time = CONVERT( nvarchar, DATEADD(mi, 0, GETDATE()), 14);
	SET @end_time   = CONVERT( nvarchar, DATEADD(mi, 10, GETDATE()), 14);

	DECLARE @retval		int
	SET @retval 		= 1
	EXEC @retval = [dbo].[sp_deny_logon] [LGN_Session_Handling], @start_day, @start_time, @end_day, @end_time
	IF ( @retval <> 0 )
	BEGIN
		SET @error_message = N'TESTRESULT: FAIL [Session_Handling_004] Falure executing sp_deny_login';
		PRINT @error_message
		RETURN;
	END

	PRINT 'TESTRESULT: PASS [Session_Handling_004]';
END TRY
BEGIN CATCH

	SET @error_message = N'TESTRESULT: FAIL [Session_Handling_004] ' + error_message();
	PRINT @error_message

END CATCH
go

--------------------------------------------------------------------------------------------------------
-- Cleanup ALL accounts and objects
--------------------------------------------------------------------------------------------------------
IF ( OBJECT_ID( N'SCH_Session_Handling_004.TBL_Session_Handling_004' ) IS NOT NULL )
BEGIN
	DROP TABLE [SCH_Session_Handling_004].[TBL_Session_Handling_004];
END
go

IF ( SCHEMA_ID( N'SCH_Session_Handling_004' ) IS NOT NULL )
BEGIN
	DROP SCHEMA [SCH_Session_Handling_004];
END
go

IF ( USER_ID( N'USR_Session_Handling_004' ) IS NOT NULL )
BEGIN
	DROP USER [USR_Session_Handling_004];
END
go
